Welcome to django-contactform’s documentation! — django-contactform 2.0.0 documentation

# Welcome to django-contactform’s documentation!

## Prerequisites

- Django >= 3.0

- Python >= 3.5

## Topics

- Install
  - Requirements
  - Enable the app
- Settings
  - CONTACTFORM_RECIPIENTS
  - CONTACTFORM_SUBJECT
  - CONTACTFORM_MSG_TEMPLATE
  - CONTACTFORM_FRONTEND_FRAMEWORK
  - CONTACTFORM_USE_THANKS_PAGE
  - CONTACTFORM_DISPLAY_FORM_TITLE
- Templates
  - Base template
  - View templates
  - Form templates
- Template Tags
  - Display a new form
  - Display an existing form
  - Keyword arguments

# Indices and tables

- Index

- Module Index

- Search Page